Learn R Programming

trotter (version 0.6)

[,APV-method: Retrieve an Amalgam by Index

Description

Access an amalgam (permutation with replacement) stored in an APV instance by index.

Usage

"["(x, i, j, drop)

Arguments

x
an instance of APV.
i
an index specifying the position of the sought amalgam
j
not used.
drop
not used.

Value

the amalgam located at position i in pseudo-vector x

Details

The amalgam at index i of pseudo-vector x is not actually stored in memory but calculated as needed. The extract method is used solely for interpretation.

See Also

Permutations Pseudo-Vector ppv

Combinations Pseudo-Vector cpv

Selections Pseudo-Vector spv

Subsets Pseudo-Vector sspv